package at.ac.uibk.gitsearch.repository.gitlab;

import java.util.Optional;

import org.gitlab4j.api.Constants.TokenType;
import org.gitlab4j.api.GitLabApi;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Repository;

import at.ac.uibk.gitsearch.config.ApplicationProperties;
import at.ac.uibk.gitsearch.security.jwt.TokenProvider;
import at.ac.uibk.gitsearch.security.jwt.TokenProvider.GitLabAccessInfo;

@Repository
public class GitLabRepository {
	
	@SuppressWarnings("unused")
	private final Logger log = LoggerFactory.getLogger(GitLabRepository.class);
	
    @Value("${application.gitlab.url}")
    private String repositoryURL;
    @Value("${application.gitlab.guestAccessToken}")
    private String guestAccessToken;
    @Value("${application.gitlab.adminAccessToken}")
    private String adminAccessToken;


	@Autowired 
	protected TokenProvider tokenProvider;
	@Autowired
	protected ApplicationProperties applicationProperties;

	
	public GitLabApi getGitLabApi() {
		Optional<String> accessTokenO = getAccessTokenOfCurrentUser();
		boolean isPresent = accessTokenO.isPresent();
		GitLabApi gitLabApi = null;
		if(isPresent) {
			String idToken = accessTokenO.get();
	         gitLabApi = new GitLabApi(repositoryURL, TokenType.OAUTH2_ACCESS, idToken);
		} else {
	         gitLabApi = getGuestGitLabApi();
		}
		return gitLabApi;
	}

	/**
	 * returns the gitlab api authenticated as guest.
	 * @return
	 */
	public GitLabApi getGuestGitLabApi() {
		GitLabApi gitLabApi;
		gitLabApi = new GitLabApi(repositoryURL, TokenType.PRIVATE, guestAccessToken);
		return gitLabApi;
	}

	public GitLabApi getGitLabApi(Optional<GitLabAccessInfo> accessInfo) {
		if(accessInfo.isPresent()) {
			 return new GitLabApi(accessInfo.get().getGitLabAccessIssuer(), TokenType.OAUTH2_ACCESS, accessInfo.get().getAccessToken());
		} 
		return new GitLabApi(repositoryURL, TokenType.PRIVATE, guestAccessToken);
	}
	
	public GitLabApi getAdminGitLabApi() {
		return new GitLabApi(repositoryURL, TokenType.PRIVATE, adminAccessToken);
	}

	public GitLabApi getGitLabApi(String oAuth2Token) {
			 return new GitLabApi(repositoryURL, TokenType.OAUTH2_ACCESS, oAuth2Token);
	}

	private Optional<String> getAccessTokenOfCurrentUser() {
		Optional<String> accessTokenO = tokenProvider.getGitLabAccessToken();
		return accessTokenO;
	}
	
    public Optional<GitLabAccessInfo> getGitLabAccessInfo() {
    	return tokenProvider.getGitLabAccessInfo();
    }

	/**
	 * @return the repositoryURL
	 */
	public String getRepositoryURL() {
		return repositoryURL;
	}


}
