package at.ac.uibk.gitsearch.service.dto;

import java.io.Serializable;
import java.util.Objects;

import io.github.jhipster.service.Criteria;
import io.github.jhipster.service.filter.Filter;
import io.github.jhipster.service.filter.IntegerFilter;
import io.github.jhipster.service.filter.LocalDateFilter;
import io.github.jhipster.service.filter.LongFilter;
import io.github.jhipster.service.filter.StringFilter;

/**
 * Criteria class for the {@link at.ac.uibk.gitsearch.domain.Likes} entity. This class is used
 * in {@link at.ac.uibk.gitsearch.web.rest.LikesResource} to receive all the possible filtering options from
 * the Http GET request parameters.
 * For example the following could be a valid request:
 * {@code /likes?id.greaterThan=5&attr1.contains=something&attr2.specified=false}
 * As Spring is unable to properly convert the types, unless specific {@link Filter} class are used, we need to use
 * fix type specific filters.
 */
public class LikesCriteria implements Serializable, Criteria {

    private static final long serialVersionUID = 1L;

    private LongFilter id;

    private LocalDateFilter date;

    private IntegerFilter userID;

    private StringFilter exerciseID;

    public LikesCriteria() {
    }

    public LikesCriteria(LikesCriteria other) {
        this.id = other.id == null ? null : other.id.copy();
        this.date = other.date == null ? null : other.date.copy();
        this.userID = other.userID == null ? null : other.userID.copy();
        this.exerciseID = other.exerciseID == null ? null : other.exerciseID.copy();
    }

    @Override
    public LikesCriteria copy() {
        return new LikesCriteria(this);
    }

    public LongFilter getId() {
        return id;
    }

    public void setId(LongFilter id) {
        this.id = id;
    }

    public LocalDateFilter getDate() {
        return date;
    }

    public void setDate(LocalDateFilter date) {
        this.date = date;
    }

    public IntegerFilter getUserID() {
        return userID;
    }

    public void setUserID(IntegerFilter userID) {
        this.userID = userID;
    }

    public StringFilter getExerciseID() {
        return exerciseID;
    }

    public void setExerciseID(StringFilter exerciseID) {
        this.exerciseID = exerciseID;
    }


    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        final LikesCriteria that = (LikesCriteria) o;
        return
            Objects.equals(id, that.id) &&
            Objects.equals(date, that.date) &&
            Objects.equals(userID, that.userID) &&
            Objects.equals(exerciseID, that.exerciseID);
    }

    @Override
    public int hashCode() {
        return Objects.hash(
        id,
        date,
        userID,
        exerciseID
        );
    }

}
