import { Component, OnInit } from '@angular/core';

import { SearchService, AutoCompletionEntry } from 'app/search/service/search-service';
import { CloudData, CloudOptions } from 'angular-tag-cloud-module';
import Color from 'ts-color-class';

import { Router } from '@angular/router';

@Component({
  selector: 'jhi-teaser-content',
  templateUrl: './teaserContent.component.html',
  styleUrls: ['./teaserContent.component.scss'],
})
export class TeaserContentComponent implements OnInit {
  public keywords: Array<AutoCompletionEntry> = new Array<AutoCompletionEntry>();
  public contributors: Array<AutoCompletionEntry> = new Array<AutoCompletionEntry>();
  public programmingLanguages: Array<AutoCompletionEntry> = new Array<AutoCompletionEntry>();

  options: CloudOptions = {
    overflow: false,
    zoomOnHover: { scale: 1.1, transitionTime: 0.5 },
    //    width: 1,
    //    height: 800,
  };
  public keywordCloudData: CloudData[] = [];
  public contributorCloudData: CloudData[] = [];
  public programmingLanguageCloudData: CloudData[] = [];

  constructor(private searchService: SearchService, private router: Router) {}

  ngOnInit(): void {
    this.searchService.getKeywordsAutoComplete('', 20).subscribe(
      (data: Array<AutoCompletionEntry>) => {
        this.keywords = data;
        this.keywordCloudData = [];
        this.keywords.forEach(kw =>
          this.keywordCloudData.push({
            text: kw.target.toString(),
            weight: Math.min(kw.hitCount.valueOf(), 10),
            color: this.randomColor('#ffaaee'),
          })
        );
      },
      () => {
        alert('Initialization of keywords failed');
      }
    );

    this.searchService.getProgrammingLanguageAutoComplete('').subscribe(
      (data: Array<AutoCompletionEntry>) => {
        this.programmingLanguages = data;
        this.programmingLanguageCloudData = [];
        this.programmingLanguages.forEach(pl =>
          this.programmingLanguageCloudData.push({
            text: pl.target.toString(),
            weight: Math.min(pl.hitCount.valueOf(), 10),
            color: this.randomColor('#2222ff'),
          })
        );
      },
      () => {
        alert('Initialization of programming languages failed');
      }
    );
    this.searchService.getContributorCreatorAutoComplete('', 10).subscribe(
      (data: Array<AutoCompletionEntry>) => {
        this.contributors = data;
        this.contributorCloudData = [];
        this.contributors.forEach(pl =>
          this.contributorCloudData.push({
            text: pl.target.toString(),
            weight: Math.min(pl.hitCount.valueOf(), 10),
            color: this.randomColor('#aaff44'),
          })
        );
      },
      () => {
        alert('Initialization of contributors failed');
      }
    );
  }

  onKeywordClick(event: CloudData): void {
    this.clickKeyword(event.text);
  }

  onProgrammingLanguageClick(event: CloudData): void {
    this.clickLanguage(event.text);
  }

  onContributorClick(event: CloudData): void {
    this.clickContributor(event.text);
  }

  clickLanguage(programmingLanguage: String): void {
    this.router.navigate(['/search'], { queryParams: { pl: programmingLanguage } });
  }

  clickContributor(contributor: String): void {
    this.router.navigate(['/search'], { queryParams: { a: contributor } });
  }

  clickKeyword(keyWord: String): void {
    this.router.navigate(['/search'], { queryParams: { kw: keyWord } });
  }

  private randomColor(mainColorHex: string): string {
    try {
      const main = new Color(mainColorHex);
      const deviation = new Color(mainColorHex);
      const upperBound = new Color(
        Math.min(main.getRed() + deviation.getRed(), 255),
        Math.min(main.getGreen() + deviation.getGreen(), 255),
        Math.min(main.getBlue() + deviation.getBlue(), 255)
      );
      const target = new Color(
        Math.max(Math.round(upperBound.getRed() - 2 * deviation.getRed() * Math.random()), 0),
        Math.max(Math.round(upperBound.getGreen() - 2 * deviation.getGreen() * Math.random()), 0),
        Math.max(Math.round(upperBound.getBlue() - 2 * deviation.getBlue() * Math.random()), 0)
      );
      return target.getHex();
    } catch (e) {
      // console.warn("Cannot create Color:" + e.message);
      return mainColorHex;
    }
  }
}
