package at.ac.uibk.gitsearch.service;

import static at.ac.uibk.gitsearch.web.rest.AccountResourceIT.TEST_USER_LOGIN;
import static org.junit.Assert.assertEquals;

import java.io.IOException;

import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.elasticsearch.client.RestHighLevelClient;
import org.elasticsearch.node.NodeValidationException;
import org.junit.jupiter.api.BeforeAll;
import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.security.test.context.support.WithMockUser;

import at.ac.uibk.gitsearch.GitsearchApp;
import at.ac.uibk.gitsearch.repository.search.testESService.ElasticSearchTestServerConfiguration;
import at.ac.uibk.gitsearch.service.dto.StatisticsDTO;

@SpringBootTest(classes = GitsearchApp.class)
@WithMockUser(value = TEST_USER_LOGIN, authorities = "sharing")
public class AchievementServiceIT {
	@SuppressWarnings("unused")
	private static final Logger LOGGER = LogManager.getLogger(AchievementServiceIT.class);

	@Autowired
	RestHighLevelClient elasticsearchTestClient;

	@BeforeAll
	public static void setUpESServer() throws IOException, NodeValidationException {
		ElasticSearchTestServerConfiguration.getTestInstance().startTestNode();
	}

	@BeforeEach
	public void setUpIndex() {
	}

	@Autowired
	AchievementService achievementService;

	@Autowired
	SearchService searchService;

	@Autowired
	private StatisticsService statisticsService;

	@Test
	public void testSearchUserStatisticsEmpty() throws IOException {
		final StatisticsDTO result = achievementService.searchUserStatistics(" ");
		assertEquals(Integer.valueOf(0), result.getDownloads());
		assertEquals(Integer.valueOf(0), result.getViews());
	}

	@Test
	public void testSearchUserStatisticsValid() throws IOException {

		StatisticsDTO newStats = new StatisticsDTO();
		newStats.setDownloads(1);
		newStats.setViews(1);
		newStats.setExerciseID("143");
		statisticsService.save(newStats);

		final StatisticsDTO result = achievementService.searchUserStatistics("stefan.podlipnig@tuwien.ac.at");
		assertEquals(Integer.valueOf(1), result.getDownloads());
		assertEquals(Integer.valueOf(1), result.getViews());
	}
}
